package org.ovirt.engine.ui.webadmin;

import org.ovirt.engine.ui.common.CommonApplicationResources;

import com.google.gwt.resources.client.ImageResource;

public interface ApplicationResources extends CommonApplicationResources {

    @Source("images/bg.png")
    ImageResource bgImage();

    @Source("images/bookmark.gif")
    ImageResource bookmarkImage();

    @Source("images/but_erase_search_bar_text_normal.png")
    ImageResource clearSearchImage();

    @Source("images/but_erase_search_bar_text_hover.png")
    ImageResource clearSearchImage_mouseOver();

    @Source("images/but_erase_search_bar_text_mousedown.png")
    ImageResource clearSearchImage_mouseDown();

    @Source("images/cluster.png")
    ImageResource clusterImage();

    @Source("images/clusters.png")
    ImageResource clustersImage();

    @Source("images/console_disabled.png")
    ImageResource consoleDisabledImage();

    @Source("images/console.png")
    ImageResource consoleImage();

    @Source("images/datacenter.png")
    ImageResource dataCenterImage();

    @Source("images/desktop.gif")
    ImageResource desktopImage();

    @Override
    @Source("images/disk.png")
    ImageResource diskImage();

    @Source("images/error.gif")
    ImageResource errorImage();

    @Source("images/events_gray.png")
    ImageResource eventsGrayImage();

    @Source("images/events.png")
    ImageResource eventsImage();

    @Source("images/btn_guide_hover.png")
    ImageResource guideHoverMediumImage();

    @Source("images/guide.png")
    ImageResource guideImage();

    @Source("images/btn_guide.png")
    ImageResource guideMediumImage();

    @Source("images/btn_guide_pressed.png")
    ImageResource guidePressedMediumImage();

    @Source("images/icn_guide_disabled.png")
    ImageResource guideSmallDisabledImage();

    @Source("images/icn_guide.png")
    ImageResource guideSmallImage();

    @Source("images/bookmark.gif")
    ImageResource headerSearchBookmarkImage();

    @Source("images/search_button.png")
    ImageResource headerSearchButtonImage();

    @Source("images/host_error.gif")
    ImageResource hostErrorImage();

    @Source("images/host.png")
    ImageResource hostImage();

    @Source("images/host_installing.png")
    ImageResource hostInstallingImage();

    @Source("images/hosts.png")
    ImageResource hostsImage();

    @Source("images/Lock.png")
    ImageResource lockImage();

    /* Login popup resources */
    @Source("images/login/login_page_header_image.png")
    ImageResource loginPopupHeaderImage();

    @Source("images/login/login_page_header_logo.png")
    ImageResource loginPopupHeaderLogoImage();

    @Source("images/login/login_page_header_title.png")
    ImageResource loginPopupHeaderTitleImage();

    @Source("images/logo.png")
    ImageResource logoImage();

    @Source("images/host_maintenance.png")
    ImageResource maintenanceImage();

    @Source("images/many_desktops.png")
    ImageResource manyDesktopsImage();

    @Source("images/minus.png")
    ImageResource minusImage();

    @Source("images/monitor.png")
    ImageResource monitorImage();

    @Source("images/nonoperational.png")
    ImageResource nonOperationalImage();

    @Source("images/pause.gif")
    ImageResource pauseImage();

    @Source("images/icn_pause_disabled.png")
    ImageResource pauseVmDisabledImage();

    @Source("images/icn_pause.png")
    ImageResource pauseVmImage();

    @Source("images/play.gif")
    ImageResource playImage();

    @Source("images/plus_disabled.png")
    ImageResource plusDisabledImage();

    @Source("images/plus.png")
    ImageResource plusImage();

    //    @Source("images/question_mark.png")
    //    ImageResource questionMarkImage();

    @Source("images/log_warning.gif")
    ImageResource alertImage();

    @Source("images/tag_locked.png")
    ImageResource readOnlyTagImage();

    @Source("images/icn_play_disabled.png")
    ImageResource runVmDisabledImage();

    @Source("images/icn_play.png")
    ImageResource runVmImage();

    @Source("images/search_button.png")
    ImageResource searchButtonImage();

    @Source("images/server.png")
    ImageResource serverImage();

    @Source("images/split.png")
    ImageResource splitImage();

    @Source("images/split-rotate.png")
    ImageResource splitRotateImage();

    @Source("images/stop.gif")
    ImageResource stopImage();

    @Source("images/icn_stop_disabled.png")
    ImageResource stopVmDisabledImage();

    @Source("images/icn_stop.png")
    ImageResource stopVmImage();

    @Source("images/storages.png")
    ImageResource storagesImage();

    @Source("images/system.png")
    ImageResource systemImage();

    @Source("images/tag.png")
    ImageResource tagImage();

    @Source("images/icn_tag_link_disabled.gif")
    ImageResource tagLinkDisabledImage();

    @Source("images/icn_tag_link.png")
    ImageResource tagLinkImage();

    @Source("images/tag_pin_green.png")
    ImageResource tagPinGreenImage();

    @Source("images/tag_pin.png")
    ImageResource tagPinImage();

    @Source("images/torn_chain.png")
    ImageResource tornChainImage();

    @Source("images/unconfigured.png")
    ImageResource unconfiguredImage();

    @Source("images/upalert.png")
    ImageResource upalertImage();

    @Source("images/user_group.png")
    ImageResource userGroupImage();

    @Source("images/vm.png")
    ImageResource vmImage();

    @Source("images/window_bg.png")
    ImageResource windowBgImage();

    @Source("images/window_header.png")
    ImageResource windowHeaderImage();

    @Source("images/wrench.png")
    ImageResource wrenchImage();

    @Source("images/plusButton.png")
    ImageResource plusButtonImage();

    @Source("images/enlarge_bottom_panel.png")
    ImageResource enlargeFooterPanelImage();

    @Source("images/button/footer_button_start.png")
    ImageResource footerButtonUpStart();

    @Source("images/button/footer_button_stretch.png")
    ImageResource footerButtonUpStretch();

    @Source("images/button/footer_button_end.png")
    ImageResource footerButtonUpEnd();

    @Source("images/button/footer_button_Down_start.png")
    ImageResource footerButtonDownStart();

    @Source("images/button/footer_button_Down_stretch.png")
    ImageResource footerButtonDownStretch();

    @Source("images/button/footer_button_Down_end.png")
    ImageResource footerButtonDownEnd();

    @Source("images/icon_task.png")
    ImageResource iconTask();

    @Source("images/icon_audit.png")
    ImageResource iconAudit();

    @Source("images/icon_disable.png")
    ImageResource iconDisable();

    @Source("images/icon_enforce.png")
    ImageResource iconEnforce();

    @Source("images/icon_collapse_all.png")
    ImageResource collapseAllIcon();

    @Source("images/network/arrow_left.png")
    ImageResource arrowLeft();

    @Source("images/network/arrow_right_bottom.png")
    ImageResource arrowRightBottom();

    @Source("images/network/arrow_right_middle.png")
    ImageResource arrowRightMiddle();

    @Source("images/network/arrow_right_one.png")
    ImageResource arrowRightOne();

    @Source("images/network/arrow_right_top.png")
    ImageResource arrowRightTop();

    @Source("images/network/item_draggable.png")
    ImageResource itemDraggable();

    @Source("images/network/mgmt_net.png")
    ImageResource mgmtNetwork();

    @Source("images/network/network_monitor.png")
    ImageResource networkMonitor();

    @Source("images/network/network_vm.png")
    ImageResource networkVm();

    @Source("images/network/nic_down.png")
    ImageResource nicDown();

    @Source("images/network/nic_up.png")
    ImageResource nicUp();

    @Source("images/network/edit_hover.png")
    ImageResource editHover();

    @Source("images/network/edit_mousedown.png")
    ImageResource editMouseDown();

    @Source("images/network/nic_icon.png")
    ImageResource nicIcon();

    @Source("images/network/bond.png")
    ImageResource bond();

    @Source("images/network/network_not_sync.png")
    ImageResource networkNotSyncImage();

    @Source("images/network/but_erase_net_mousedown.png")
    ImageResource butEraseNetMousedown();

    @Source("images/network/but_erase_net_hover.png")
    ImageResource butEraseNetHover();

    @Source("images/cluster_gluster.png")
    ImageResource glusterClusterImage();

    @Source("images/single_volume.png")
    ImageResource volumeImage();

    @Source("images/multiple_volumes.png")
    ImageResource volumesImage();

    @Source("images/marketplace_in_rhev.png")
    ImageResource linkImage();
}
